==> keycloak-model-map-hot-rod-20.0.2-sources.jar: org/keycloak/models/map/storage/hotRod/loginFailure/HotRodUserLoginFailureEntityDescriptor.java <==
package org.keycloak.models.map.storage.hotRod.loginFailure;
import org.infinispan.protostream.GeneratedSchema;
import java.util.function.Function;
public class HotRodUserLoginFailureEntityDescriptor implements org.keycloak.models.map.storage.hotRod.common.HotRodEntityDescriptor<org.keycloak.models.map.storage.hotRod.loginFailure.HotRodUserLoginFailureEntity, org.keycloak.models.map.storage.hotRod.loginFailure.HotRodUserLoginFailureEntityDelegate> {
    @Override
    public Class<?> getModelTypeClass() {
        return org.keycloak.models.UserLoginFailureModel.class;
    }
    @Override
    public Class<org.keycloak.models.map.storage.hotRod.loginFailure.HotRodUserLoginFailureEntity> getEntityTypeClass() {
        return org.keycloak.models.map.storage.hotRod.loginFailure.HotRodUserLoginFailureEntity.class;
    }
    @Override
    public String getCacheName() {
        return org.keycloak.models.map.storage.ModelEntityUtil.getModelName(org.keycloak.models.UserLoginFailureModel.class);
    }
    @Override
    public Function<org.keycloak.models.map.storage.hotRod.loginFailure.HotRodUserLoginFailureEntity, org.keycloak.models.map.storage.hotRod.loginFailure.HotRodUserLoginFailureEntityDelegate> getHotRodDelegateProvider() {
        return org.keycloak.models.map.storage.hotRod.loginFailure.HotRodUserLoginFailureEntityDelegate::new;
    }
    @Override
    public Integer getCurrentVersion() {
        return org.keycloak.models.map.storage.hotRod.loginFailure.HotRodUserLoginFailureEntity.VERSION;
    }
    @Override
    public GeneratedSchema getProtoSchema() {
        return org.keycloak.models.map.storage.hotRod.loginFailure.HotRodUserLoginFailureEntity.HotRodUserLoginFailureEntitySchema.INSTANCE;
    }
}

==> keycloak-model-map-hot-rod-22.0.5-sources.jar: org/keycloak/models/map/storage/hotRod/loginFailure/HotRodUserLoginFailureEntityDescriptor.java <==
package org.keycloak.models.map.storage.hotRod.loginFailure;
import org.infinispan.protostream.GeneratedSchema;
import java.util.function.Function;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateHotRodEntityImplementationsProcessor")
public class HotRodUserLoginFailureEntityDescriptor implements org.keycloak.models.map.storage.hotRod.common.HotRodEntityDescriptor<org.keycloak.models.map.storage.hotRod.loginFailure.HotRodUserLoginFailureEntity, org.keycloak.models.map.storage.hotRod.loginFailure.HotRodUserLoginFailureEntityDelegate> {
    @Override
    public Class<?> getModelTypeClass() {
        return org.keycloak.models.UserLoginFailureModel.class;
    }
    @Override
    public Class<org.keycloak.models.map.storage.hotRod.loginFailure.HotRodUserLoginFailureEntity> getEntityTypeClass() {
        return org.keycloak.models.map.storage.hotRod.loginFailure.HotRodUserLoginFailureEntity.class;
    }
    @Override
    public String getCacheName() {
        return org.keycloak.models.map.storage.ModelEntityUtil.getModelName(org.keycloak.models.UserLoginFailureModel.class);
    }
    @Override
    public Function<org.keycloak.models.map.storage.hotRod.loginFailure.HotRodUserLoginFailureEntity, org.keycloak.models.map.storage.hotRod.loginFailure.HotRodUserLoginFailureEntityDelegate> getHotRodDelegateProvider() {
        return org.keycloak.models.map.storage.hotRod.loginFailure.HotRodUserLoginFailureEntityDelegate::new;
    }
    @Override
    public Integer getCurrentVersion() {
        return org.keycloak.models.map.storage.hotRod.loginFailure.HotRodUserLoginFailureEntity.VERSION;
    }
    @Override
    public GeneratedSchema getProtoSchema() {
        return org.keycloak.models.map.storage.hotRod.loginFailure.HotRodUserLoginFailureEntity.HotRodUserLoginFailureEntitySchema.INSTANCE;
    }
}
